Omeka S Tools
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

`pip install omeka-s-tools2`

## How to use

[See the
documentation](https://nakamura196.github.io/omeka_s_tools/api.html) for
full details of the Omeka API Client.

``` python
from omeka_s_tools2.api import *

omeka = OmekaAPIClient('http://timsherratt.org/collections/api')
```

``` python
items = omeka.get_resources('items')
items['total_results']
```

    140

``` python
items['results'][0]
```

    {'@context': 'http://timsherratt.org/collections/api-context',
     '@id': 'http://timsherratt.org/collections/api/items/677',
     '@type': ['o:Item', 'schema:Newspaper'],
     'o:id': 677,
     'o:is_public': True,
     'o:owner': {'@id': 'http://timsherratt.org/collections/api/users/1',
      'o:id': 1},
     'o:resource_class': {'@id': 'http://timsherratt.org/collections/api/resource_classes/161',
      'o:id': 161},
     'o:resource_template': {'@id': 'http://timsherratt.org/collections/api/resource_templates/5',
      'o:id': 5},
     'o:thumbnail': None,
     'o:title': 'Manilla Express (NSW : 1899 - 1954)',
     'thumbnail_display_urls': {'large': 'http://timsherratt.org/collections/files/large/aa1fb4063116fc889418ce6dc20af3cb7e7bd0db.jpg',
      'medium': 'http://timsherratt.org/collections/files/medium/aa1fb4063116fc889418ce6dc20af3cb7e7bd0db.jpg',
      'square': 'http://timsherratt.org/collections/files/square/aa1fb4063116fc889418ce6dc20af3cb7e7bd0db.jpg'},
     'o:created': {'@value': '2022-01-20T06:37:50+00:00',
      '@type': 'http://www.w3.org/2001/XMLSchema#dateTime'},
     'o:modified': {'@value': '2022-01-20T06:37:50+00:00',
      '@type': 'http://www.w3.org/2001/XMLSchema#dateTime'},
     'o:media': [{'@id': 'http://timsherratt.org/collections/api/media/882',
       'o:id': 882},
      {'@id': 'http://timsherratt.org/collections/api/media/897', 'o:id': 897},
      {'@id': 'http://timsherratt.org/collections/api/media/929', 'o:id': 929},
      {'@id': 'http://timsherratt.org/collections/api/media/994', 'o:id': 994},
      {'@id': 'http://timsherratt.org/collections/api/media/995', 'o:id': 995},
      {'@id': 'http://timsherratt.org/collections/api/media/996', 'o:id': 996},
      {'@id': 'http://timsherratt.org/collections/api/media/997', 'o:id': 997}],
     'o:item_set': [],
     'o:site': [],
     'schema:name': [{'type': 'literal',
       'property_id': 1116,
       'property_label': 'name',
       'is_public': True,
       '@value': 'Manilla Express (NSW : 1899 - 1954)'}],
     'schema:url': [{'type': 'uri',
       'property_id': 393,
       'property_label': 'url',
       'is_public': True,
       '@id': 'http://nla.gov.au/nla.news-title1006'}],
     'schema:identifier': [{'type': 'literal',
       'property_id': 190,
       'property_label': 'identifier',
       'is_public': True,
       '@value': '1006'}],
     '@reverse': []}

See [the
documentation](https://nakamura196.github.io/omeka_s_tools/api.html) for
more examples.

------------------------------------------------------------------------

Created by [Tim Sherratt](https://timsherratt.org)
([@wragge](https://twitter.com/wragge)) for the [GLAM
Workbench](https://glam-workbench.net/).  
Created by [@satoru196](https://twitter.com/satoru196).
